"""
simple devices
"""
from . import ai, ao, bi, bo
from . import scaler, struck, mca, transform, scan

ai = ai.ai
ao = ao.ao
bi = bi.bi
bo = bo.bo
Scaler = scaler.Scaler
Struck = struck.Struck
Mca = mca.Mca
Transform  = transform.Transform



